#
# spec file for package update-checker
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%if 0%{?is_opensuse}
%define service_list update-checker.service update-checker.timer
%else
%define service_list update-checker-migration.service update-checker.service update-checker-migration.timer update-checker.timer
%endif

%define rb_build_versions %{rb_default_ruby}
%define rb_build_abi      %{rb_default_ruby_abi}
%define rb_suffix         %{rb_default_ruby_suffix}

Name:           update-checker
Version:        1.0+git20181210.70430e2
Release:        20.3
Summary:        Scripts to check for new updates and migration targets
License:        GPL-2.0-or-later
Group:          Development/Tools/Other
Url:            https://github.com/thkukuk/update-checker
Source:         update-checker-%{version}.tar.xz
Patch:          update-checker.conf-CaaSP.patch
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  docbook-xsl-stylesheets
BuildRequires:  docbook_4
BuildRequires:  libxslt-tools
BuildRequires:  python3
BuildRequires:  python3-lxml
Requires:       perl-Config-IniFiles
Requires:       perl-XML-Twig
%if !0%{?is_opensuse}
Requires:       %{rubygem suse-connect >= 0.3.11}
Requires:       %{rubygem inifile >= 3.0.0}
%endif
BuildArch:      noarch

%description
Files, scripts and configuration files for two systemd services:
one, which checks for new, not applied updates and one which checks
for new migration targets.

%prep
%setup -q
%if 0%{?is_susecaasp}
%patch -p0
%endif

%build
./autogen.sh
%configure
make %{?_smp_mflags}

%install
%make_install
%if 0%{?is_opensuse}
rm %{buildroot}/usr/lib/systemd/system/update-checker-migration.*
rm %{buildroot}/usr/sbin/update-checker-migration
rm %{buildroot}/usr/share/man/man8/update-checker-migration.*
%endif

%pre
%service_add_pre %{service_list}

%post
%service_add_post %{service_list}

%preun
%service_del_preun %{service_list}

%postun
%service_del_postun %{service_list}

%files
%license COPYING
%config /etc/update-checker.conf
%{_unitdir}
%{_sbindir}/update-checker
%if !0%{?is_opensuse}
%{_sbindir}/update-checker-migration
%endif
%{_mandir}/man5/*
%{_mandir}/man8/*

%changelog
* Wed Jan  9 2019 jmassaguerpla@suse.com
- Fix rubygem dependencies
* Mon Dec 10 2018 kukuk@suse.de
- update-checker.conf-CaaSP.patch: change systemd profile default
  output to salt.
* Mon Dec 10 2018 kukuk@suse.de
- Update to version 1.0+git20181210.70430e2:
  * Fix fallback to global section, if special section does not exist.
  * Use systemd profile in configuration file for systemd services.
  * Document --profile option
  * Implement --profile option
  * Fix typo
  * Use rubygem-inifiles to read configuration file
- Add rubygem-inifile requirement for update-checker-migration
* Wed Dec  5 2018 kukuk@suse.de
- Update to version 1.0+git20181205.79dad1e:
  * Fix syntax error in OnCalendar entry [bsc#1118321]
* Thu Nov 29 2018 iforster@suse.de
- Update to version 1.0+git20181104.a2c4ebf:
  * Improve error checking
  * introduce profiles for configuration file, so that we can call the tool
    from commandline or from systemd with differout output.
- Fixes [boo#1117647]
* Thu Oct  4 2018 kukuk@suse.de
- Install update-checker-migration only on SLE.
* Thu Oct  4 2018 kukuk@suse.de
- Update to version 1.0+git20181004.228275e:
  * Use "C" locale for sorting.
  * Use python3 to build html pages
* Tue Oct  2 2018 kukuk@suse.de
- Add requires to perl-Config-IniFiles and SUSEConnect library
* Mon Oct  1 2018 kukuk@suse.de
- Update to version 1.0+git20181001.0248077:
  * fix variable name
* Tue Sep 25 2018 kukuk@suse.de
- Update to version 1.0+git20180925.fe4e47c: [bsc#1109777]
  * Bump version to 1.0
  * Add manual page for update-checker.8
  * Implement different output methods (stdout, issue)
  * fix wrong condition
  * Cleanup update-checker option handling
* Wed Sep  5 2018 kukuk@suse.de
- Update to version 1.0+git20180905.814bdd8:
  * Fix building of manual pages in parallel
  * Enable man sub-directory
  * Add manual pages, generate nroff and html versions.
  * Fix name in license.
  * Print error messages on stderr Catch more errors.
  * Add --output option to allow overwriting output option from config file.
* Wed Aug 22 2018 kukuk@suse.de
- Update to version 1.0+git20180822.0827e3d:
  * Only check every second and fourth week of a month, tuesday
    evening, if there is a new migration target available.
* Wed Aug 22 2018 kukuk@suse.de
- Update to version 1.0+git20180822.bff6967:
  * Fix setting if mirror_synced in case product is not mirrored yet.
* Wed Aug 22 2018 kukuk@suse.de
- Update to version 1.0+git20180822.4651cbd:
  * Implement salt grains support
* Tue Aug 21 2018 kukuk@suse.de
- Update to version 1.0+git20180821.3b2d41a:
  * Fix configure.ac and Makefiles
  * Fix generation of configure script
  * Add systemd services and timers to run the update checker scripts
* Tue Aug 21 2018 kukuk@suse.de
- Initial version
